@@ -160,11 +160,11 @@ the normalized measurement vectors:
            [-2.53039690e-02,  4.00697428e-02,  9.98876431e-01]])
 
 Optionally, it can return the estimation as a quaternion representation setting
-``as_quaternion`` to ``True``.
+``representation`` to ``'quaternion'``.
 
 .. code-block:: python
 
-    >>> triad.estimate(w1=a, w2=m, as_quaternion=True)
+    >>> triad.estimate(w1=a, w2=m, representation='quaternion')
     array([ 0.27531002, -0.00664729,  0.02275078,  0.96106327])
 
 Giving the observation vector to the constructor, the attitude estimation
@@ -177,7 +177,7 @@ happens automatically, and is stored in the attribute ``A``.
     array([[-8.48320410e-01, -5.29483162e-01, -2.49900033e-04],
            [ 5.28878238e-01, -8.47373587e-01,  4.73900062e-02],
            [-2.53039690e-02,  4.00697428e-02,  9.98876431e-01]])
-    >>> triad = ahrs.filters.TRIAD(w1=np.array([-2.499e-04, 4.739e-02, 0.9988763]), w2=np.array([-0.36663061, 0.17598138, -0.91357132]), v2=h, as_quaternion=True)
+    >>> triad = ahrs.filters.TRIAD(w1=np.array([-2.499e-04, 4.739e-02, 0.9988763]), w2=np.array([-0.36663061, 0.17598138, -0.91357132]), v2=h, representation='quaternion')
     >>> triad.A
     array([ 0.27531002, -0.00664729,  0.02275078,  0.96106327])
 
@@ -204,7 +204,7 @@ If the input data contains many observations, all will be estimated at once.
            [[-8.32771974e-01, -5.53528225e-01, -9.86626329e-03],
             [ 5.51396878e-01, -8.30896061e-01,  7.46539896e-02],
             [-4.95209297e-02,  5.67295235e-02,  9.97160688e-01]]])
-    >>> triad = ahrs.filters.TRIAD(w1=a, w2=m, as_quaternion=True)
+    >>> triad = ahrs.filters.TRIAD(w1=a, w2=m, representation='quaternion')
     >>> triad.A
     array([[ 0.27531229, -0.00664771,  0.02275202,  0.96106259],
            [ 0.2793823 , -0.01030667,  0.0268131 ,  0.95975016],
@@ -272,8 +272,7 @@ class TRIAD:
         field :math:`\\mathbf{h} = \\begin{bmatrix}h_x & h_y & h_z \\end{bmatrix}`
         in Munich, Germany.
     representation : str, default: ``'rotmat'``
-        Attitude representation. Options are ``rotmat'``, ``'quaternion'``,
-        ``'rpy'``, or ``'axisangle'``.
+        Attitude representation. Options are ``rotmat'`` or ``'quaternion'``.
     frame : str, default: 'NED'
         Local tangent plane coordinate frame. Valid options are right-handed
         ``'NED'`` for North-East-Down and ``'ENU'`` for East-North-Up.
@@ -288,8 +287,6 @@ class TRIAD:
         First tri-axial reference vector.
     v2 : numpy.ndarray, optional.
         Second tri-axial reference vector.
-    as_quaternion : bool, default: False
-        Whether to return attitude as a quaternion.
     A : numpy.ndarray
         Estimated attitude.
 
@@ -332,12 +329,12 @@ class TRIAD:
         self.v1 = self._set_first_triad_reference(v1, frame)
         self.v2 = self._set_second_triad_reference(v2, frame)
         # Compute values if samples given
-        if self.w1 is not None and self.w2 is not None:
+        if all([self.w1, self.w2]):
             self.A = self._compute_all(self.representation)
 
     def _set_first_triad_reference(self, value, frame):
         if value is None:
-            ref = np.array([0.0, 0.0, 1.0]) if frame.upper=='NED' else np.array([0.0, 0.0, -1.0])
+            ref = np.array([0.0, 0.0, 1.0]) if frame.upper == 'NED' else np.array([0.0, 0.0, -1.0])
         else:
             ref = np.copy(value)
             ref /= np.linalg.norm(ref)
@@ -348,7 +345,7 @@ class TRIAD:
         if isinstance(value, float):
             if abs(value)>90:
                 raise ValueError(f"Dip Angle must be within range [-90, 90]. Got {value}")
-            ref = np.array([cosd(value), 0.0, sind(value)]) if frame.upper()=='NED' else np.array([0.0, cosd(value), -sind(value)])
+            ref = np.array([cosd(value), 0.0, sind(value)]) if frame.upper() == 'NED' else np.array([0.0, cosd(value), -sind(value)])
         if isinstance(value, (np.ndarray, list)):
             ref = np.copy(value)
         return ref/np.linalg.norm(ref)
@@ -362,7 +359,7 @@ class TRIAD:
         Parameters
         ----------
         representation : str
-            Attitude representation. Options are ``rotmat'`` or ``'quaternion'``
+            Attitude representation. Options are ``'rotmat'`` or ``'quaternion'``.
 
         Returns
         -------
@@ -374,10 +371,10 @@ class TRIAD:
         """
         if self.w1.shape!=self.w2.shape:
             raise ValueError("w1 and w2 are not the same size")
-        if self.w1.ndim==1:
+        if self.w1.ndim == 1:
             return self.estimate(self.w1, self.w2, representation)
         num_samples = len(self.w1)
-        A = np.zeros((num_samples, 4)) if representation.lower()=='quaternion' else np.zeros((num_samples, 3, 3))
+        A = np.zeros((num_samples, 4)) if representation.lower() == 'quaternion' else np.zeros((num_samples, 3, 3))
         for t in range(num_samples):
             A[t] = self.estimate(self.w1[t], self.w2[t], representation)
         return A
@@ -394,15 +391,15 @@ class TRIAD:
             Sample of first tri-axial sensor.
         w2 : numpy.ndarray
             Sample of second tri-axial sensor.
-        as_quaternion : bool, default: False
-            Return estimated attitude as a quaternion representation.
+        representation : str, default: ``'rotmat'``
+            Attitude representation. Options are ``rotmat'`` or ``'quaternion'``.
 
         Returns
         -------
         A : numpy.ndarray
             Estimated attitude as 3-by-3 Direction Cosine Matrix. If
-            ``as_quaternion`` is set to ``True``, it is returned as a
-            quaternion representation.
+            ``representation`` is set to ``'quaternion'``, it is returned as a
+            quaternion.
 
         Examples
         --------
@@ -415,10 +412,12 @@ class TRIAD:
         array([[-7.84261e-01  ,  4.5905718e-01,  4.1737417e-01],
                [ 2.2883429e-01, -4.1126404e-01,  8.8232463e-01],
                [ 5.7668844e-01,  7.8748232e-01,  2.1749032e-01]])
-        >>> triad.estimate(w1=a, w2=m, as_quaternion=True)          # Estimated attitude as quaternion
+        >>> triad.estimate(w1=a, w2=m, representation='quaternion')          # Estimated attitude as quaternion
         array([ 0.07410345, -0.3199659, -0.53747247, -0.77669417])
 
         """
+        if representation.lower() not in ['rotmat', 'quaternion']:
+            raise ValueError("Wrong representation type. Try 'rotmat', or 'quaternion'")
         w1, w2 = np.copy(w1), np.copy(w2)
         # Normalized Vectors
         w1 /= np.linalg.norm(w1)                            # (eq. 12-39a)
@@ -436,6 +435,6 @@ class TRIAD:
         Mr = np.c_[self.v1, r2, r3]                         # (eq. 12-42)
         A = Mb@Mr.T                                         # (eq. 12-45)
         # Return according to desired representation
-        if representation.lower()=='quaternion':
+        if representation.lower() == 'quaternion':
             return chiaverini(A)
         return A
